==> FHLBBS-5.3.tgz: php/edit.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","currboard","cbrd","read_pt","$comment1","$title1");
    $genbuf=trim($_REQUEST["board1"]);
    //$comment1=trim($_REQUEST["comment1"]);
    if (strrchr($genbuf,'/')!==false) //ȬOhacker
	die ("<h1>AOhackerܡH</h1><p>\n");
    if (strlen($genbuf)>0)
    	$currboard=$genbuf;
    $divide=$QUERY_STRING;
    //$title1=trim($_REQUEST["title1"]);
    if(strstr($divide,"reply") !== false)
       $editmode=1;
    elseif (strstr($divide,"remail")!==false)
       $editmode=4;
    elseif (strstr($divide,"mail")!==false)
      {
        $editmode=3;
	if (strcmp($cuser->userid,"guest")==0)
            die("GuestSHHvQI<p>\n");
      }
    elseif (strstr($divide,"reauth")!==false)
        $editmode=2;
    else
        $editmode=0;
 
    /*** QװϬ ***/
	if ($editmode < 3)
	{
	  $cbrd=searchbrd($currboard);
          if ((!$cbrd)||(!Ben_Perm($cbrd)))
		die("S $currboard oӰQװϡI<p>\n");
          $currmode=0;
         if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM($cbrd->BM)))
          {
             $currmode |= (MODE_BOARD | MODE_POST);
          }
          elseif (haspostperm($cbrd)) $currmode |= MODE_POST;
          while ((!(($currmode)&(MODE_POST)))&&($editmode<2))
	  {
	     if (strcasecmp($cuser->userid,"guest")==0)
	      {
		authenticate();
		auth();
		/*****spv*****/
                if ((!$cbrd)||(!Ben_Perm($cbrd)))
		     die("S $currboard oӰQװϡI<p>\n");
                if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM($cbrd->BM)))
                {
                    $currmode |= (MODE_BOARD | MODE_POST);
                }
	      }
	    else //not guest 
	        die ("藍_AzثeLkbo峹I<p>\n");
	  }
	}
      //٨S
   
   $buf2=$DEFDIR[$doorid].$prefile[$editmode];
   if( ($fp = fopen($buf2,"r")) ===false  ) //}榡
       die ("{$buf2}ɮ׶}ҿ~<br>");
   $replyfile=new dirrec;
       /*}lBz榡 ****/
   while (!feof($fp))
    {
        $genbuf=fgets($fp,1000);
        $pt1=$genbuf;
        while (!(($pt2=strpos($pt1,"<!--$"))===false))
        {
           $bpt2=substr($pt1,0,$pt2);
           echo "$bpt2";/* LXtokener */
           $pt1=substr($pt1,$pt2+5);
           $ptmode=(int) $pt1;//নƦr
           $pt3=strpos($pt1,"-->");
           if ($pt3===false)
                        die ("榡ɿ~IP@椺䤣 -->");
            $pt1=substr($pt1,$pt3+3);
            if ($ptmode>0)   SSI($ptmode);
            else   //Dn\
            {
               /**** ^Ҧ *************/
      	      if (($editmode==1)||($editmode==2)||($editmode==4)) 
              {
	          if (($editmode==1)||($editmode==2))
		     $buf1=$BBSHOME."/boards/{$currboard}/.DIR";
	          else
		     $buf1=sethomedir($cuser->userid);
		  $numposts = filesize($buf1)/$dirlength;
                  /*** ɮ׽sѼƧѼơA_hsession ܼƭ ***/
		  $numarticle=(int) $_REQUEST["numarticle"];
		  if ($numarticle == 0) $numarticle=$read_pt; //session 
		  if ($numarticle < 1) $numarticle=1;
		  if ($numarticle > $numposts) $numarticle=$numposts;
		  if( ($fd = fopen( $buf1, "r" )) ===false )
                        die (".DIR }ҿ~I");
                  fseek($fd, $dirlength*($numarticle-1), SEEK_SET);
                  $genbuf=fread($fd, $dirlength);
                  $replyfile->unpack($genbuf);
	          fclose($fd);
		  /*** BzD ******/
	          if(strncmp($replyfile->title,"Re: ",4) == 0)
	             $title1=$replyfile->title;
	          else
	             $title1="Re: ".$replyfile->title;
		  if (strlen($comment1)==0)//Ĥ@i
		  {
	          	$comment1=" ޭzm{$replyfile->owner}nʨG\n";
	          	if (($editmode==1)||($editmode==2))
	              		$filename1=$BBSHOME."/boards/{$currboard}/{$replyfile->filename}";
	          	else
	              		$filename1=sethomefile($cuser->userid,$replyfile->filename); 
                  	/****Bzި ***/
	          	if(($fptr1 = fopen($filename1, "r")) !== false) 
                  	{
		    	   $lpad=": ";
   		    	   while (!feof($fptr1))
    		    	   {
        			$linebuf=fgets($fptr1,1000);
		        	if(strncasecmp($linebuf, "</pre><p></font>", 16) == 0) break;
				/* 屼ñW */
                        	if(strncmp($linebuf,"--",2)==0) break;
				if(strlen(trim($linebuf))>3) $comment1=$comment1.$lpad.$linebuf;
		    	   }
 	            	  fclose($fptr1);
	           	}//fopen($filename1
		  }
	      } // edit mode =1 ,2, 4
	    if ($editmode<2)
	        echo "zO:{$cuser->userid}<p>\n";
	    elseif (($editmode==4)||($editmode==2))
	    {
	     	echo "^HG{$replyfile->owner}<p>\n";
	        echo "<input type=\"hidden\" name=\"RECEIVER\" value=\"{$replyfile->owner}\"><p>\n";
	    }
	    else  // edit mode = 3
            {
		$buf1=trim($_REQUEST["id"]);
		if (strlen($buf1)>0) /** idi **/
                    echo "HH:{$buf1}<input type=\"hidden\" name=\"RECEIVER\" value=\"{$buf1}\"><p>\n";
                else 
                    echo "HH:<input type=\"text\" name=\"RECEIVER\" size=12 maxlength=12><p>\n";
            }
            $tspec=str_replace("&","&amp;",$tspec);
            $tspec=str_replace("\"","&quot;",$title1);
            $tspec=str_replace(">","&gt;",$tspec);
            $tspec=str_replace("<","&lt;",$tspec);
	    echo "D:<input type=\"text\" name=\"title1\" size= $BTLEN maxlength= $BTLEN value=\"{$tspec}\"><p>\n";
	   if(($editmode==1)||($editmode==2)||($editmode==4)) 
           {  //o̦ݭnܡH٬OzL sessionH
	        //echo "<input type=\"hidden\" name=\"replytitle\" value=\"{$replyfile->title}\"><p>\n";
	        //echo "<input type=\"hidden\" name=\"replyfilename\" value=\"{$replyfile->filename}\"><p>\n";
	        //echo "<input type=\"hidden\" name=\"numarticle\" value=\"{$numarticle}\"><p>\n";
	    }
	   if ($editmode<3)
           {
	        echo "<input type=\"hidden\" name=\"board1\" value=\"{$currboard}\"><p>\n";
                echo "<input type=\"hidden\" name=\"WHERE\" value=\"0\"><p>\n";
           }
	   else
          {
	        echo "<input type=\"hidden\" name=\"board1\" value=\"mail\">\n";
                echo "<input type=\"hidden\" name=\"WHERE\" value=\"1\"><p>\n";
          }
          if ($editmode<2) 
                echo "<input type=\"hidden\" name=\"TARGET\" value=\"0\"><p>\n";
          else
                echo "<input type=\"hidden\" name=\"TARGET\" value=\"1\"><p>\n";
          echo "峹JϡG<br>\n";
	  echo "<textarea name=\"comment1\" rows=15 cols=70>{$comment1}</textarea><p>\n";  
          /*** BzñW **/
          $sign=((int) $cuser->uflag) & SIG_FLAG;
          if ($sign==0)
          {
             echo "<input type=\"radio\" value=\"0\" name=\"SIGNYN\" checked>[ñW";
             echo "<input type=\"radio\" value=\"1\" name=\"SIGNYN\">[ñW";
             echo " ϥñW<input type=\"text\" value=\"1\" name=\"SIGNFILE\" size=2 maxlength=1>";
          }
          else
         {
             echo "<input type=\"radio\" value=\"0\" name=\"SIGNYN\">[ñW";
             echo "<input type=\"radio\" value=\"1\" name=\"SIGNYN\" checked>[ñW";
             echo " ϥñW<input type=\"text\" value=\"{$sign}\" name=\"SIGNFILE\" size=2 maxlength=1>";
         }
         /*** BzHP_ ***/
         if ($editmode<2)
         {
             echo "<input type=\"radio\" value=\"1\" name=\"LOCALSAVE\" checked>ѻPH";
             echo "<input type=\"radio\" value=\"0\" name=\"LOCALSAVE\">峹";
         }
      } //ptmode
     } // while pt2=
     echo $pt1;   
   } //while get line
    fclose($fp);   
?>

==> FHLBBS-5.4.tgz: php/edit.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","currboard","cbrd","read_pt","comment1","title1","ismail");
    $genbuf=trim($_REQUEST["board1"]);
    //$comment1=trim($_REQUEST["comment1"]);
    if (strrchr($genbuf,'/')!==false) //ȬOhacker
	die ("<h1>AOhackerܡH</h1><p>\n");
    if (strlen($genbuf)>0)
    	$currboard=$genbuf;
    $divide=$QUERY_STRING;
    //$title1=trim($_REQUEST["title1"]);
    if(strstr($divide,"reply") !== false) //^QװϤ峹
       $editmode=1;
    elseif (strstr($divide,"remail")!==false) //^l
       $editmode=4;
    elseif (strstr($divide,"mail")!==false) //gl
      {
        $editmode=3;
	if (strcmp($cuser->userid,"guest")==0)
            die("GuestSHHvQI<p>\n");
      }
    elseif (strstr($divide,"reauth")!==false) //^H@
        $editmode=2;
    else
        $editmode=0;  //@iK峹
    if ($editmode >1) $ismail=1; //edit mode 234
    else $ismail=0;
 
    /*** QװϬ ***/
	if ($editmode < 3)
	{
	  $cbrd=searchbrd($currboard);
          if ((!$cbrd)||(!Ben_Perm($cbrd)))
		die("S $currboard oӰQװϡI<p>\n");
          $currmode=0;
         if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM($cbrd->BM)))
          {
             $currmode |= (MODE_BOARD | MODE_POST);
          }
          elseif (haspostperm($cbrd)) $currmode |= MODE_POST;
          while ((!(($currmode)&(MODE_POST)))&&($editmode<2))
	  {
	     if (strcasecmp($cuser->userid,"guest")==0)
	      {
		authenticate();
		auth();
		/*****spv*****/
                if ((!$cbrd)||(!Ben_Perm($cbrd)))
		     die("S $currboard oӰQװϡI<p>\n");
                if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM($cbrd->BM)))
                {
                    $currmode |= (MODE_BOARD | MODE_POST);
                }
	      }
	    else //not guest 
	        die ("藍_AzثeLkbo峹I<p>\n");
	  }
	}
      //٨S
   
   $buf2=$DEFDIR[$doorid].$prefile[$editmode];
   if( ($fp = fopen($buf2,"r")) ===false  ) //}榡
       die ("{$buf2}ɮ׶}ҿ~<br>");
   $replyfile=new dirrec;
       /*}lBz榡 ****/
   while (!feof($fp))
    {
        $genbuf=fgets($fp,1000);
        $pt1=$genbuf;
        while (!(($pt2=strpos($pt1,"<!--$"))===false))
        {
           $bpt2=substr($pt1,0,$pt2);
           echo "$bpt2";/* LXtokener */
           $pt1=substr($pt1,$pt2+5);
           $ptmode=(int) $pt1;//নƦr
           $pt3=strpos($pt1,"-->");
           if ($pt3===false)
                        die ("榡ɿ~IP@椺䤣 -->");
            $pt1=substr($pt1,$pt3+3);
            if ($ptmode>0)   SSI($ptmode);
            else   //Dn\
            {
               /**** ^Ҧ *************/
      	      if (($editmode==1)||($editmode==2)||($editmode==4)) 
              {
	          if (($editmode==1)||($editmode==2))
		     $buf1=$BBSHOME."/boards/{$currboard}/.DIR";
	          else
		     $buf1=sethomedir($cuser->userid);
		  $numposts = filesize($buf1)/$dirlength;
                  /*** ɮ׽sѼƧѼơA_hsession ܼƭ ***/
		  $numarticle=(int) $_REQUEST["numarticle"];
		  if ($numarticle == 0) $numarticle=$read_pt; //session 
		  if ($numarticle < 1) $numarticle=1;
		  if ($numarticle > $numposts) $numarticle=$numposts;
		  if( ($fd = fopen( $buf1, "r" )) ===false )
                        die (".DIR }ҿ~I");
                  fseek($fd, $dirlength*($numarticle-1), SEEK_SET);
                  $genbuf=fread($fd, $dirlength);
                  $replyfile->unpack($genbuf);
	          fclose($fd);
		  /*** BzD ******/
	          if(strncmp($replyfile->title,"Re: ",4) == 0)
	             $title1=$replyfile->title;
	          else
	             $title1="Re: ".$replyfile->title;
		  if (strlen($comment1)==0)//Ĥ@i
		  {
	          	$comment1=" ޭzm{$replyfile->owner}nʨG\n";
	          	if (($editmode==1)||($editmode==2))
	              		$filename1=$BBSHOME."/boards/{$currboard}/{$replyfile->filename}";
	          	else
	              		$filename1=sethomefile($cuser->userid,$replyfile->filename); 
                  	/****Bzި ***/
	          	if(($fptr1 = fopen($filename1, "r")) !== false) 
                  	{
		    	   $lpad=": ";
   		    	   while (!feof($fptr1))
    		    	   {
        			$linebuf=fgets($fptr1,1000);
		        	if(strncasecmp($linebuf, "</pre><p></font>", 16) == 0) break;
				/* 屼ñW */
                        	if(strncmp($linebuf,"--",2)==0) break;
				if(strlen(trim($linebuf))>3) $comment1=$comment1.$lpad.$linebuf;
		    	   }
 	            	  fclose($fptr1);
	           	}//fopen($filename1
		  }
	      } // edit mode =1 ,2, 4
	    if ($editmode<2)
	        echo "zO:{$cuser->userid}<p>\n";
	    elseif (($editmode==4)||($editmode==2))
	    {
	     	echo "^HG{$replyfile->owner}<p>\n";
	        echo "<input type=\"hidden\" name=\"RECEIVER\" value=\"{$replyfile->owner}\"><p>\n";
	    }
	    else  // edit mode = 3
            {
		$buf1=trim($_REQUEST["id"]);
		if (strlen($buf1)>0) /** idi **/
                    echo "HH:{$buf1}<input type=\"hidden\" name=\"RECEIVER\" value=\"{$buf1}\"><p>\n";
                else 
                    echo "HH:<input type=\"text\" name=\"RECEIVER\" size=12 maxlength=12><p>\n";
            }
            $tspec=str_replace("&","&amp;",$tspec);
            $tspec=str_replace("\"","&quot;",$title1);
            $tspec=str_replace(">","&gt;",$tspec);
            $tspec=str_replace("<","&lt;",$tspec);
	    echo "D:<input type=\"text\" name=\"title1\" size= $BTLEN maxlength= $BTLEN value=\"{$tspec}\"><p>\n";
	   /********************** by tjm 20030729
	   if(($editmode==1)||($editmode==2)||($editmode==4)) 
           {  //o̦ݭnܡH٬OzL sessionH
	        //echo "<input type=\"hidden\" name=\"replytitle\" value=\"{$replyfile->title}\"><p>\n";
	        //echo "<input type=\"hidden\" name=\"replyfilename\" value=\"{$replyfile->filename}\"><p>\n";
	        //echo "<input type=\"hidden\" name=\"numarticle\" value=\"{$numarticle}\"><p>\n";
	    }
	    ************************/
	   if ($editmode<3)
           {
	        echo "<input type=\"hidden\" name=\"board1\" value=\"{$currboard}\"><p>\n";
                echo "<input type=\"hidden\" name=\"WHERE\" value=\"0\"><p>\n";
           }
	   else
          {
	        echo "<input type=\"hidden\" name=\"board1\" value=\"mail\">\n";
                echo "<input type=\"hidden\" name=\"WHERE\" value=\"1\"><p>\n";
          }
          if ($editmode<2) 
                echo "<input type=\"hidden\" name=\"TARGET\" value=\"0\"><p>\n";
          else
                echo "<input type=\"hidden\" name=\"TARGET\" value=\"1\"><p>\n";
          echo "峹JϡG<br>\n";
	  echo "<textarea name=\"comment1\" rows=15 cols=70>{$comment1}</textarea><p>\n";  
          /*** BzñW **/
          $sign=((int) $cuser->uflag) & SIG_FLAG;
          if ($sign==0)
          {
             echo "<input type=\"radio\" value=\"0\" name=\"SIGNYN\" checked>[ñW";
             echo "<input type=\"radio\" value=\"1\" name=\"SIGNYN\">[ñW";
             echo " ϥñW<input type=\"text\" value=\"1\" name=\"SIGNFILE\" size=2 maxlength=1>";
          }
          else
         {
             echo "<input type=\"radio\" value=\"0\" name=\"SIGNYN\">[ñW";
             echo "<input type=\"radio\" value=\"1\" name=\"SIGNYN\" checked>[ñW";
             echo " ϥñW<input type=\"text\" value=\"{$sign}\" name=\"SIGNFILE\" size=2 maxlength=1>";
         }
         /*** BzHP_ ***/
         if ($editmode<2)
         {
             echo "<input type=\"radio\" value=\"1\" name=\"LOCALSAVE\" checked>ѻPH";
             echo "<input type=\"radio\" value=\"0\" name=\"LOCALSAVE\">峹";
         }
      } //ptmode
     } // while pt2=
     echo $pt1;   
   } //while get line
    fclose($fp);   
?>
